<?php
/**
 * Helper functions for the admin - plugin links and help tabs.
 *
 * @package    Genesis Widgetized Footer
 * @subpackage Admin
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright 2012, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-widgetized-footer/
 * @link       http://twitter.com/deckerweb
 *
 * @since 1.0.0
 */

/**
 * Setting internal plugin helper links constants.
 *
 * @since 1.2.0
 */
define( 'GWFOOT_URL_TRANSLATE',		'http://translate.wpautobahn.com/projects/genesis-plugins-deckerweb/genesis-widgetized-footer' );
define( 'GWFOOT_URL_WPORG_FAQ',		'http://wordpress.org/extend/plugins/genesis-widgetized-footer/faq/' );
define( 'GWFOOT_URL_WPORG_FORUM',	'http://wordpress.org/support/plugin/genesis-widgetized-footer' );
define( 'GWFOOT_URL_WPORG_PROFILE',	'http://profiles.wordpress.org/daveshine/' );
define( 'GWFOOT_URL_SNIPPETS',		'https://gist.github.com/2497456' );
define( 'GWFOOT_PLUGIN_LICENSE', 	'GPLv2+' );
if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
	define( 'GWFOOT_URL_DONATE', 	'http://genesisthemes.de/spenden/' );
	define( 'GWFOOT_URL_PLUGIN',	'http://genesisthemes.de/plugins/genesis-widgetized-footer/' );
} else {
	define( 'GWFOOT_URL_DONATE', 	'http://genesisthemes.de/en/donate/' );
	define( 'GWFOOT_URL_PLUGIN',	'http://genesisthemes.de/en/wp-plugins/genesis-widgetized-footer/' );
}


/**
 * Add "Widgets Page" link to plugin page.
 *
 * @since 1.0.0
 *
 * @param  $gwfoot_links
 * @param  $gwfoot_widgets_link
 *
 * @return strings Widgets link
 */
function ddw_gwfoot_widgets_page_link( $gwfoot_links ) {

	/** Widgets Admin link */
	$gwfoot_widgets_link = sprintf( '<a href="%s" title="%s">%s</a>' , admin_url( 'widgets.php' ) , __( 'Go to the Widgets settings page', 'genesis-widgetized-footer' ) , __( 'Widgets', 'genesis-widgetized-footer' ) );

	/** Set the order of the links */
	array_unshift( $gwfoot_links, $gwfoot_widgets_link );

	/** Display plugin settings links */
	return $gwfoot_links;

}  // end of function ddw_gwfoot_widgets_page_link


add_filter( 'plugin_row_meta', 'ddw_gwfoot_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page.
 *
 * @since 1.0.0
 *
 * @param  $gwfoot_links
 * @param  $gwfoot_file
 *
 * @return strings plugin links
 */
function ddw_gwfoot_plugin_links( $gwfoot_links, $gwfoot_file ) {

	/** Capability check */
	if ( ! current_user_can( 'install_plugins' ) ) {

		return $gwfoot_links;

	}  // end-if cap check

	/** List additional links only for this plugin */
	if ( $gwfoot_file == GWFOOT_PLUGIN_BASEDIR . '/genesis-widgetized-footer.php' ) {

		$gwfoot_links[] = '<a href="' . esc_url_raw( GWFOOT_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'genesis-widgetized-footer' ) . '">' . __( 'FAQ', 'genesis-widgetized-footer' ) . '</a>';
		$gwfoot_links[] = '<a href="' . esc_url_raw( GWFOOT_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'genesis-widgetized-footer' ) . '">' . __( 'Support', 'genesis-widgetized-footer' ) . '</a>';
		$gwfoot_links[] = '<a href="' . esc_url_raw( GWFOOT_URL_SNIPPETS ) . '" target="_new" title="' . __( 'Code Snippets for Customization', 'genesis-widgetized-footer' ) . '">' . __( 'Code Snippets', 'genesis-widgetized-footer' ) . '</a>';
		$gwfoot_links[] = '<a href="' . esc_url_raw( GWFOOT_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'genesis-widgetized-footer' ) . '">' . __( 'Translations', 'genesis-widgetized-footer' ) . '</a>';
		$gwfoot_links[] = '<a href="' . esc_url_raw( GWFOOT_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'genesis-widgetized-footer' ) . '"><strong>' . __( 'Donate', 'genesis-widgetized-footer' ) . '</strong></a>';

	}  // end-if plugin links

	/** Output the links */
	return $gwfoot_links;

}  // end of function ddw_gwfoot_plugin_links


add_action( 'sidebar_admin_setup', 'ddw_gwfoot_widgets_help' );
/**
 * Load plugin help tab after core help tabs on Widget admin page.
 *
 * @since 1.1.0
 *
 * @global mixed $pagenow
 */
function ddw_gwfoot_widgets_help() {

	global $pagenow;

	add_action ( 'admin_head-' . $pagenow, 'ddw_gwfoot_widgets_help_tab' );

}  // end of function ddw_gwfoot_widgets_help


add_action( 'load-toplevel_page_genesis', 'ddw_gwfoot_widgets_help_tab', 16 );			// Genesis Core
add_action( 'load-genesis_page_seo-settings', 'ddw_gwfoot_widgets_help_tab', 16 );		// Genesis SEO
add_action( 'load-genesis_page_genesis-import-export', 'ddw_gwfoot_widgets_help_tab', 16 );	// Genesis Import/Export
add_action( 'load-genesis_page_design-settings', 'ddw_gwfoot_widgets_help_tab', 16 );		// Prose Child Theme
add_action( 'load-genesis_page_prose-custom', 'ddw_gwfoot_widgets_help_tab', 16 );		// Prose Custom Section
add_action( 'load-genesis_page_dynamik-settings', 'ddw_gwfoot_widgets_help_tab', 16 );		// Dynamik Child Theme
add_action( 'load-genesis_page_dynamik-design', 'ddw_gwfoot_widgets_help_tab', 16 );		// Dynamik Child Design
add_action( 'load-genesis_page_dynamik-custom', 'ddw_gwfoot_widgets_help_tab', 16 );		// Dynamik Custom Section
/**
 * Create and display plugin help tab.
 *
 * @since 1.1.0
 *
 * @global mixed $gwfoot_widgets_screen, $pagenow
 */
function ddw_gwfoot_widgets_help_tab() {

	global $gwfoot_widgets_screen, $pagenow;

	$gwfoot_widgets_screen = get_current_screen();

	/** Display help tabs only for WordPress 3.3 or higher */
	if ( ! class_exists( 'WP_Screen' )
		|| ! $gwfoot_widgets_screen
		|| basename( get_template_directory() ) != 'genesis'
	) {
		return;
	}

//

	/** Add the new help tab */
	$gwfoot_widgets_screen->add_help_tab( array(
		'id'      => 'gwfoot-widgets-help',
		'title'   => __( 'Genesis Widgetized Footer', 'genesis-widgetized-footer' ),
		'callback' => 'ddw_gwfoot_widgets_help_content',
	) );

	/** Add help sidebar */
	if ( $pagenow != 'widgets.php' ) {

		$gwfoot_widgets_screen->set_help_sidebar(
			'<p><strong>' . __( 'More about the plugin author', 'genesis-widgetized-footer' ) . '</strong></p>' .
			'<p>' . __( 'Social:', 'genesis-widgetized-footer' ) . '<br /><a href="http://twitter.com/deckerweb" target="_blank" title="@ Twitter">Twitter</a> | <a href="http://www.facebook.com/deckerweb.service" target="_blank" title="@ Facebook">Facebook</a> | <a href="http://deckerweb.de/gplus" target="_blank" title="@ Google+">Google+</a> | <a href="' . esc_url_raw( ddw_gwfoot_plugin_get_data( 'AuthorURI' ) ) . '" target="_blank" title="@ deckerweb.de">deckerweb</a></p>' .
			'<p><a href="' . esc_url_raw( GWFOOT_URL_WPORG_PROFILE ) . '" target="_blank" title="@ WordPress.org">@ WordPress.org</a></p>'
		);

	}  // end-if $pagehook check

}  // end of function ddw_gwfoot_widgets_help_tab


/**
 * Create and display plugin help tab content.
 *
 * @since 1.0.0
 *
 * @uses ddw_gwfoot_plugin_get_data() To display various data of this plugin.
 */
function ddw_gwfoot_widgets_help_content() {

	/** Helper string */
	$gwfoot_constant_help = ' &ndash; ' . sprintf( __( 'optional, could be deactivated %svia constant%s', 'genesis-widgetized-footer' ), '<a href="' . esc_url_raw( GWFOOT_URL_SNIPPETS ) . '" target="_blank" title="' . __( 'Code Snippets for Customization', 'genesis-widgetized-footer' ) . '">', '</a>' );

	echo '<h3>' . __( 'Plugin', 'genesis-widgetized-footer' ) . ': ' . __( 'Genesis Widgetized Footer', 'genesis-widgetized-footer' ) . ' <small>v' . esc_attr( ddw_gwfoot_plugin_get_data( 'Version' ) ) . '</small></h3>';
	
	echo '<p>' . __( 'Added Widget areas by the plugin - only displayed if having active widgets placed in:', 'genesis-widgetized-footer' ) .
		'<ul>' . 
			'<li>' . __( 'Footer Area #1', 'genesis-widgetized-footer' ) . '</li>' .
			'<li>' . __( 'Footer Area #2', 'genesis-widgetized-footer' ) . '</li>' .
			'<li>' . __( 'Footer Disclaimer', 'genesis-widgetized-footer' ) . $gwfoot_constant_help . '</li>' .
		'</ul>';

	echo '<p>' . __( 'The Genesis Footer Shortcodes plus regular WordPress Shortcodes are supported in all three widget areas.', 'genesis-widgetized-footer' ) . '<br />&raquo; <a href="http://www.studiopress.com/tutorials/shortcode-reference#footer-shortcodes" target="_new" title="' . __( 'Genesis Shortcode Reference here...', 'genesis-widgetized-footer' ) . '">' . __( 'Genesis Shortcode Reference here...', 'genesis-widgetized-footer' ) . '</a></p>';

	echo '<p><strong>' . __( 'Important plugin links:', 'genesis-widgetized-footer' ) . '</strong>' . 
		'<br /><a href="' . esc_url_raw( GWFOOT_URL_PLUGIN ) . '" target="_new" title="' . __( 'Plugin website', 'genesis-widgetized-footer' ) . '">' . __( 'Plugin website', 'genesis-widgetized-footer' ) . '</a> | <a href="' . esc_url_raw( GWFOOT_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'genesis-widgetized-footer' ) . '">' . __( 'FAQ', 'genesis-widgetized-footer' ) . '</a> | <a href="' . esc_url_raw( GWFOOT_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'genesis-widgetized-footer' ) . '">' . __( 'Support', 'genesis-widgetized-footer' ) . '</a> | <a href="' . esc_url_raw( GWFOOT_URL_SNIPPETS ) . '" target="_new" title="' . __( 'Code Snippets for Customization', 'genesis-widgetized-footer' ) . '">' . __( 'Code Snippets', 'genesis-widgetized-footer' ) . '</a> | <a href="' . esc_url_raw( GWFOOT_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'genesis-widgetized-footer' ) . '">' . __( 'Translations', 'genesis-widgetized-footer' ) . '</a> | <a href="' . esc_url_raw( GWFOOT_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'genesis-widgetized-footer' ) . '"><strong>' . __( 'Donate', 'genesis-widgetized-footer' ) . '</strong></a></p>';

	echo '<p><a href="http://www.opensource.org/licenses/gpl-license.php" target="_new" title="' . esc_attr( GWFOOT_PLUGIN_LICENSE ). '">' . esc_attr( GWFOOT_PLUGIN_LICENSE ). '</a> &copy; ' . date( 'Y' ) . ' <a href="' . esc_url_raw( ddw_gwfoot_plugin_get_data( 'AuthorURI' ) ) . '" target="_new" title="' . esc_attr__( ddw_gwfoot_plugin_get_data( 'Author' ) ) . '">' . esc_attr__( ddw_gwfoot_plugin_get_data( 'Author' ) ) . '</a></p>';

}  // end of function ddw_gwfoot_widgets_help_content
