<?php
/**
 * Helper function in case of landing page templates - logic for the frontend display.
 *
 * @package    Genesis Widgetized Footer
 * @subpackage Frontend
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright 2012, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-widgetized-footer/
 * @link       http://twitter.com/deckerweb
 *
 * @since 1.2.0
 */

add_action( 'genesis_before', 'gwfoot_landing_templates_undo_footer_widgets', 15 );
/**
 * Helper function for removing Footer Widget areas on landing page templates.
 * Fires also on 'genesis_before' hook but with lower priority.
 *
 * @since 1.2.0
 */
function gwfoot_landing_templates_undo_footer_widgets() {

	/**
	 * Check for landing page templates.
	 *
	 * Helper constant allows for custom disabling.
	 * Usage: define( 'GWFOOT_REMOVE_LANDING_FOOTER', FALSE );
	 */
	if ( GWFOOT_REMOVE_LANDING_FOOTER
		&& ( is_page_template( 'page_landing.php' )
			|| is_page_template( 'page-landing.php' )
			|| is_page_template( 'landing.php' )
			|| is_page_template( 'template-landing.php' )
			|| is_page_template( 'template_page-landing.php' )
		)
	) {

		/** Check against Prose 1.0/1.5.x Child Theme (official) */
		if ( defined( 'PROSE_SETTINGS_FIELD' ) ) {

			remove_action( 'genesis_after', 'gwfoot_display_footer_one_section' );
			remove_action( 'genesis_after', 'gwfoot_display_footer_two_section' );

		}
		/** Otherwise default behavior */
		else {

			remove_action( 'genesis_footer', 'gwfoot_display_footer_one_section' );
			remove_action( 'genesis_footer', 'gwfoot_display_footer_two_section' );

		}  // end-if child theme check

	}  // end-if constant & landing page template check

}  // end of function gwfoot_landing_templates_undo_footer_widgets
